@@ -169,7 +169,6 @@ class PitiviMainWindow(gtk.Window, Loggable):
         self.actions = None
         self.toggleactions = None
         self.actiongroup = None
-        self.error_dialogbox = None
         self.settings = instance.settings
         self.is_fullscreen = self.settings.mainWindowFullScreen
         self.timelinepos = 0
@@ -178,6 +177,7 @@ class PitiviMainWindow(gtk.Window, Loggable):
         self._setActions(instance)
         self._createUi(instance)
         self.app = instance
+        self._zoom_duration_changed = False
 
         self.app.projectManager.connect("new-project-loading",
                 self._projectManagerNewProjectLoadingCb)
@@ -202,9 +202,12 @@ class PitiviMainWindow(gtk.Window, Loggable):
         self.app.action_log.connect("cleaned", self._actionLogCleaned)
 
         # if no webcams available, hide the webcam action
-        self.app.deviceprobe.connect("device-added", self._deviceChangeCb)
-        self.app.deviceprobe.connect("device-removed", self._deviceChangeCb)
-        if len(self.app.deviceprobe.getVideoSourceDevices()) < 1:
+        if self.app.deviceprobe is not None:
+            self.app.deviceprobe.connect("device-added", self._deviceChangeCb)
+            self.app.deviceprobe.connect("device-removed", self._deviceChangeCb)
+            if len(self.app.deviceprobe.getVideoSourceDevices()) < 1:
+                self.webcam_button.set_sensitive(False)
+        else:
             self.webcam_button.set_sensitive(False)
 
         self.show()
@@ -364,29 +367,35 @@ class PitiviMainWindow(gtk.Window, Loggable):
         # main menu & toolbar
         vbox = gtk.VBox(False)
         self.add(vbox)
+        vbox.show()
         self.menu = self.uimanager.get_widget("/MainMenuBar")
         vbox.pack_start(self.menu, expand=False)
+        self.menu.show()
         self.toolbar = self.uimanager.get_widget("/MainToolBar")
         vbox.pack_start(self.toolbar, expand=False)
+        self.toolbar.show()
         # timeline and project tabs
         vpaned = gtk.VPaned()
         vbox.pack_start(vpaned)
+        vpaned.show()
 
         self.timeline = Timeline(instance, self.uimanager)
         self.timeline.project = self.project
 
         vpaned.pack2(self.timeline, resize=False, shrink=False)
+        self.timeline.show()
         hpaned = gtk.HPaned()
         vpaned.pack1(hpaned, resize=True, shrink=False)
+        hpaned.show()
         self.projecttabs = ProjectTabs()
 
         self.sourcelist = SourceList(instance, self.uimanager)
         self.projecttabs.append_page(self.sourcelist, gtk.Label(_("Clip Library")))
         self._connectToSourceList()
+        self.sourcelist.show()
 
         hpaned.pack1(self.projecttabs, resize=True, shrink=False)
-
-        self.timeline.ruler.connect('seek', self._timelineRulerSeekCb)
+        self.projecttabs.show()
 
         # Viewer
         self.viewer = PitiviViewer()
@@ -396,6 +405,7 @@ class PitiviMainWindow(gtk.Window, Loggable):
                            gtk.gdk.ACTION_COPY)
         self.viewer.connect("drag_data_received", self._viewerDndDataReceivedCb)
         hpaned.pack2(self.viewer, resize=False, shrink=False)
+        self.viewer.show()
         self.viewer.connect("expose-event", self._exposeEventCb)
 
         # window and pane position defaults
@@ -425,8 +435,9 @@ class PitiviMainWindow(gtk.Window, Loggable):
         # very bottom of the screen.
         ttb = self.uimanager.get_widget("/TimelineToolBar")
         vbox.pack_start(ttb, expand=False)
+        ttb.show()
 
-        self.show_all()
+        self.show()
 
         if not self.settings.mainWindowShowMainToolbar:
             self.toolbar.props.visible = False
@@ -435,12 +446,12 @@ class PitiviMainWindow(gtk.Window, Loggable):
             ttb.props.visible = False
 
         #application icon
-        self.set_icon_from_file(get_global_pixmap_dir()
-            + "/pitivi.png")
+        self.set_icon_name("pitivi")
+
+        #pulseaudio 'role' (http://0pointer.de/blog/projects/tagging-audio.htm
+        os.environ["PULSE_PROP_media.role"] = "production"
 
     def _connectToSourceList(self):
-        # FIXME: projecttabs creates the "components" but then has no API to get
-        # them back
         self.sourcelist.connect('play', self._sourceListPlayCb)
 
     def toggleFullScreen(self):
@@ -468,11 +479,6 @@ class PitiviMainWindow(gtk.Window, Loggable):
         pane.pack2(self.viewer, resize=False, shrink=False)
         self.viewer.show()
 
-    def _errorMessageResponseCb(self, dialogbox, unused_response):
-        dialogbox.hide()
-        dialogbox.destroy()
-        self.error_dialogbox = None
-
 ## Missing Plugin Support
 
     def _installPlugins(self, details, missingPluginsCallback):
@@ -527,6 +533,7 @@ class PitiviMainWindow(gtk.Window, Loggable):
             action=gtk.FILE_CHOOSER_ACTION_OPEN,
             buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
                 gtk.STOCK_OPEN, gtk.RESPONSE_OK))
+        chooser.set_icon_name("pitivi")
         chooser.set_select_multiple(False)
         chooser.set_current_folder(self.settings.lastProjectFolder)
         formats = formatter.list_formats()
@@ -617,7 +624,8 @@ class PitiviMainWindow(gtk.Window, Loggable):
         abt.set_authors(authors)
         abt.set_license(_("GNU Lesser General Public License\n"
                           "See http://www.gnu.org/copyleft/lesser.html for more details"))
-        abt.set_icon_from_file(get_global_pixmap_dir() + "/pitivi.png")
+        abt.set_icon_name("pitivi")
+        abt.set_logo_icon_name("pitivi")
         abt.connect("response", self._aboutResponseCb)
         abt.show()
 
@@ -692,36 +700,21 @@ class PitiviMainWindow(gtk.Window, Loggable):
 
         if project.timeline.duration != 0:
             self._setBestZoomRatio()
+        else:
+            self._zoom_duration_changed = True
+
+        self.project.seeker.connect("seek", self._timelineSeekCb)
+
+        # preliminary seek to ensure the project pipeline is configured
+        self.project.seeker.seek(0)
 
     def _setBestZoomRatio(self):
-        # reset the default zoom ratio
-        Zoomable.setZoomRatio(2)
-
         ruler_width = self.timeline.ruler.get_allocation()[2]
-        while True:
-            timeline_width = Zoomable.nsToPixel(self.project.timeline.duration)
+        timeline_duration = self.project.timeline.duration
 
-            if ruler_width == timeline_width:
-                # perfect
-                break
-
-            current_level = Zoomable.getCurrentZoomLevel()
-
-            if ruler_width > timeline_width:
-                if current_level == Zoomable.zoom_levels[-1]:
-                    break
-
-                Zoomable.zoomIn()
-                timeline_width = Zoomable.nsToPixel(self.project.timeline.duration)
-                if timeline_width > ruler_width:
-                    Zoomable.zoomOut()
-                    break
-
-            else:
-                if current_level == Zoomable.zoom_levels[0]:
-                    break
-
-                Zoomable.zoomOut()
+        ideal_zoom_ratio = ruler_width / float(timeline_duration / gst.SECOND)
+        nearest_zoom_level = Zoomable.computeZoomLevel(ideal_zoom_ratio)
+        Zoomable.setZoomLevel(nearest_zoom_level)
 
     def _projectManagerNewProjectLoadingCb(self, projectManager, uri):
         self.log("A NEW project is being loaded, deactivate UI")
@@ -745,15 +738,15 @@ class PitiviMainWindow(gtk.Window, Loggable):
             save = gtk.STOCK_SAVE
         else:
             save = gtk.STOCK_SAVE_AS
-        dialog = gtk.Dialog(_("Close project"),
+
+        dialog = gtk.Dialog("",
             self, gtk.DIALOG_MODAL | gtk.DIALOG_NO_SEPARATOR,
             (_("Close without saving"), gtk.RESPONSE_REJECT,
                     gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
                     save, gtk.RESPONSE_YES))
-        dialog.set_border_width(5)
+        dialog.set_icon_name("pitivi")
         dialog.set_resizable(False)
         dialog.set_has_separator(False)
-        dialog.set_skip_taskbar_hint(False)
         dialog.set_default_response(gtk.RESPONSE_YES)
 
         primary = gtk.Label()
@@ -762,26 +755,35 @@ class PitiviMainWindow(gtk.Window, Loggable):
         primary.set_alignment(0, 0.5)
 
         message = _("Save changes to the current project before closing?")
-        primary.set_markup("<span weight=\"bold\" size=\"larger\">" +
-                message + "</span>")
-        secondary = gtk.Label(_("If you don't save some of your "
-                "changes will be lost"))
-        secondary.set_line_wrap(True)
-        vbox = gtk.VBox(False, 12)
-        vbox.pack_start(primary)
-        vbox.pack_start(secondary)
+        primary.set_markup("<span weight=\"bold\">" + message + "</span>")
 
+        secondary = gtk.Label()
+        secondary.set_line_wrap(True)
+        secondary.set_use_markup(True)
+        secondary.set_alignment(0, 0.5)
+        secondary.props.label = _("If you don't save some of your "
+                "changes will be lost")
+
+        # put the text in a vbox
+        vbox = gtk.VBox(False, 12)
+        vbox.pack_start(primary, expand=True, fill=True)
+        vbox.pack_start(secondary, expand=True, fill=True)
+
+        # make the [[image] text] hbox
         image = gtk.image_new_from_stock(gtk.STOCK_DIALOG_WARNING,
                gtk.ICON_SIZE_DIALOG)
         hbox = gtk.HBox(False, 12)
-        hbox.set_border_width(5)
-        hbox.pack_start(image)
-        hbox.pack_start(vbox)
-        content_area = dialog.get_content_area()
-        content_area.pack_start(hbox)
-        content_area.set_spacing(14)
+        hbox.pack_start(image, expand=False)
+        hbox.pack_start(vbox, expand=True, fill=True)
         action_area = dialog.get_action_area()
-        action_area.set_layout(gtk.BUTTONBOX_DEFAULT_STYLE)
+        # FIXME: find out where this "6" comes from. It's needed to align our
+        # hbox with the action area button box
+        hbox.set_border_width(6)
+
+        # stuff the hbox in the dialog
+        content_area = dialog.get_content_area()
+        content_area.pack_start(hbox, expand=True, fill=True)
+        content_area.set_spacing(14)
         hbox.show_all()
 
         response = dialog.run()
@@ -803,6 +805,7 @@ class PitiviMainWindow(gtk.Window, Loggable):
         self._disconnectFromProjectSources(project.sources)
         self.viewer.setAction(None)
         self.viewer.setPipeline(None)
+        project.seeker.disconnect_by_func(self._timelineSeekCb)
         return False
 
     def _projectManagerNewProjectFailedCb(self, projectManager, uri, exception):
@@ -813,6 +816,7 @@ class PitiviMainWindow(gtk.Window, Loggable):
             gtk.BUTTONS_OK,
             _("PiTiVi is unable to load file \"%s\"") %
                 uri)
+        dialog.set_icon_name("pitivi")
         dialog.set_title(_("Error Loading File"))
         dialog.set_property("secondary-text", str(exception))
         dialog.run()
@@ -825,13 +829,13 @@ class PitiviMainWindow(gtk.Window, Loggable):
             gtk.DIALOG_MODAL,
             buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
             gtk.STOCK_OPEN, gtk.RESPONSE_OK))
+        dialog.set_icon_name("pitivi")
         dialog.set_border_width(12)
         dialog.get_content_area().set_spacing(6)
 
-        text = _("The following file has moved," +
-            " please tell PiTiVi where to find it.") + "\n\n" + \
-            beautify_factory(factory) + "\n" +\
-            _("<b>Duration:</b>") + beautify_length(factory.duration)
+        text = _("The following file has moved, please tell PiTiVi where to find it.") + \
+            "\n\n" + beautify_factory(factory) + "\n" + \
+            "<b>%s</b>" % _("Duration:") + beautify_length(factory.duration)
 
         label = gtk.Label()
         label.set_markup(text)
@@ -917,10 +921,10 @@ class PitiviMainWindow(gtk.Window, Loggable):
     project = receiver(_setProject)
 
     @handler(project, "settings-changed")
-    def _settingsChangedCb(self, project):
+    def _settingsChangedCb(self, project, old, new):
         if self.viewer.action == self.project.view_action:
-            sett = self.project.getSettings()
-            self.viewer.setDisplayAspectRatio(float(sett.videopar * sett.videowidth) / float(sett.videoheight))
+            self.viewer.setDisplayAspectRatio(float(new.videopar *
+            new.videowidth) / float(new.videoheight))
 
     def _sourceListMissingPluginsCb(self, project, uri, factory,
             details, descriptions, missingPluginsCallback):
@@ -939,22 +943,10 @@ class PitiviMainWindow(gtk.Window, Loggable):
 
     @handler(project_pipeline, "error")
     def _pipelineErrorCb(self, unused_pipeline, error, detail):
-        # FIXME FIXME FIXME:
-        # _need_ an onobtrusive way to present gstreamer errors,
-        # one that doesn't steel mouse/keyboard focus, one that
-        # makes some kind of sense to the user, and one that presents
-        # some ways of actually _dealing_ with the underlying problem:
-        # install a plugin, re-conform source to some other format, or
-        # maybe even disable playback of a problematic file.
-        if self.error_dialogbox:
-            return
-        self.error_dialogbox = gtk.MessageDialog(None, gtk.DIALOG_MODAL,
-            gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, None)
-        self.error_dialogbox.set_markup("<b>%s</b>" % error)
-        self.error_dialogbox.connect("response", self._errorMessageResponseCb)
         if detail:
-            self.error_dialogbox.format_secondary_text(detail)
-        self.error_dialogbox.show()
+            self.timeline.infostub.addErrors(error, detail)
+        else:
+            self.timeline.infostub.addErrors(error)
 
     @handler(project_pipeline, "position")
     def _timelinePipelinePositionChangedCb(self, pipeline, position):
@@ -973,6 +965,9 @@ class PitiviMainWindow(gtk.Window, Loggable):
     def _timelineDurationChangedCb(self, timeline, duration):
         if duration > 0:
             sensitive = True
+            if self._zoom_duration_changed:
+                self._setBestZoomRatio()
+                self._zoom_duration_changed = False
         else:
             sensitive = False
         self.render_button.set_sensitive(sensitive)
@@ -987,6 +982,7 @@ class PitiviMainWindow(gtk.Window, Loggable):
             buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
             gtk.STOCK_SAVE, gtk.RESPONSE_OK))
 
+        chooser.set_icon_name("pitivi")
         chooser.set_select_multiple(False)
         chooser.set_current_name(_("Untitled.xptv"))
         chooser.set_current_folder(self.settings.lastProjectFolder)
@@ -1052,15 +1048,17 @@ class PitiviMainWindow(gtk.Window, Loggable):
         action = ViewAction()
         action.addProducers(factory)
         self.viewer.setPipeline(None)
+        self.viewer.showSlider()
         # FIXME: why do I have to call viewer.setAction ?
         self.viewer.setAction(action)
         self.viewer.setPipeline(pipeline)
         self.viewer.play()
 
-    def _timelineRulerSeekCb(self, ruler, position):
+    def _timelineSeekCb(self, ruler, position, format):
         self.debug("position:%s", gst.TIME_ARGS (position))
         if self.viewer.action != self.project.view_action:
             self.viewer.setPipeline(None)
+            self.viewer.hideSlider()
             self.viewer.setAction(self.project.view_action)
             self.viewer.setPipeline(self.project.pipeline)
             # get the pipeline settings and set the DAR of the viewer
@@ -1070,7 +1068,7 @@ class PitiviMainWindow(gtk.Window, Loggable):
         # set to the pipeline.
         self.project.pipeline.pause()
         try:
-            self.project.pipeline.seek(position)
+            self.project.pipeline.seek(position, format)
         except:
             self.debug("Seeking failed")
 
